require 'openssl'
require 'base64'

module Bluekai
  # A simple BlueKai client
  class Client
    attr_reader :domain, :api_user_key

    def initialize(opts = {})
      @api_user_key = opts.fetch(:api_user_key, ENV['BLUEKAI_API_USER_KEY']) ||
        fail(Bluekai::Error, 'BlueKai API user key missing')
      @api_private_key = opts.fetch(:api_private_key, ENV['BLUEKAI_API_PRIVATE_KEY']) ||
        fail(Bluekai::Error, 'BlueKai API private key missing')
      @partner_id = opts.fetch(:partner_id, ENV['BLUEKAI_PARTNER_ID']) ||
        fail(Bluekai::Error, 'BlueKai PartnerID missing')
      @opts = opts
    end

    def ping
      request('GET', '/Services/WS/Ping', {}) == :success rescue false
    end

    # Public: Lists categories in the BlueKai taxonomy. API definition
    # can be found here https://kb.bluekai.com/display/PD/Taxonomy+API
    #
    # parentId - integer
    # fullPath - {0,1}
    # bkSize - {0,1} Enter 1 to include the inventory of unique users in
    #          the BlueKai network for each category.
    # intlDataCountryId - {-1..24} for country index see
    #                     (https://kb.bluekai.com/display/PD/Taxonomy+API)
    # device_code - {0 = Desktop + Mobile,1 = Desktop, 2 = Mobile}
    # showBuyable - {0,1}
    # showLeafStatus - {0,1}
    # description - {0,1}
    # vertical - {0,1}
    # showReceivedAudienceCategories - {0,1}
    # showCategoryPriceAtDate - {'YYYY-MM-DD'}
    #
    # Returns array of taxonomy nodes.
    def taxonomy(query = {})
      request('GET', '/Services/WS/Taxonomy', query)[:nodeList]
    end

    private

    def request(method, path, query, body = nil)
      r = Request.new(method, path, query, body, domain)
      r.api_user_key = @api_user_key
      r.api_private_key = @api_private_key
      r.run
    end

    def domain
      'https://services.bluekai.com'
    end
  end
end
